/*
 * $Id: TexMathScanner.java,v 1.3 2006/03/23 19:53:02 borisvl Exp $
 *
 * Copyright (c) 2004-2005 by the TeXlapse Team.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package net.sourceforge.texlipse.editor.scanner;

import java.util.ArrayList;
import java.util.List;

import net.sourceforge.texlipse.editor.ColorManager;
import net.sourceforge.texlipse.editor.TexEditor;

import org.eclipse.jface.text.TextAttribute;
import org.eclipse.jface.text.rules.EndOfLineRule;
import org.eclipse.jface.text.rules.IRule;
import org.eclipse.jface.text.rules.IToken;
import org.eclipse.jface.text.rules.RuleBasedScanner;
import org.eclipse.jface.text.rules.Token;
import org.eclipse.jface.text.rules.WhitespaceRule;


/**
 * TexMathScanner is used for "__tex_mathParitition" -content type.
 * It uses defined rules to detect sequences and it returns the
 * specified token that satisfies a rule. The token defines how the
 * characters are presented.
 *  @see net.sourceforge.texlipse.editor.TexPartitionScanner
 *  @author Antti Pirinen
 */ 
public class TexMathScanner extends RuleBasedScanner {
    
    /**
     * A default constructor. 
     * @param manager
     * @param editor
     */
    public TexMathScanner(ColorManager manager, TexEditor editor) {
        IToken commentToken = new Token(
                new TextAttribute(
                        manager.getColor(ColorManager.COMMENT),
                        null,
                        manager.getStyle(ColorManager.COMMENT_STYLE)));

        
        List rules = new ArrayList();
        
        rules.add(new WhitespaceRule(new WhitespaceDetector()));
        rules.add(new EndOfLineRule("%",commentToken));
        rules.add(new TexEnvironmentRule("comment", commentToken));
        
        IRule[] result = new IRule[rules.size()];
        rules.toArray(result);
        setRules(result);		
    }
}
